BubbleContainer class

Inheritance

Constructors

BubbleContainer({Key? key, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, AlignmentGeometry? alignment, BorderRadius radius = const BorderRadius.all(Radius.circular(5)), Color color = Colors.white, BubbleType type = BubbleType.bottom, double deltaOffset = 20, double deltaLength = 10, double deltaHeight = 6, double deltaCorner = 2, double? width, double? height, Widget? child, BoxConstraints? constraints, Color? shadowColor, double shadowElevation = 5, bool shadowOccluder = false})
const

Properties

alignment AlignmentGeometry?
alignment
final
child Widget?
final
color Color
color
final
constraints BoxConstraints?
constraints
final
deltaCorner double
delta length
final
deltaHeight double
delta height
final
deltaLength double
delta length
final
deltaOffset double
offset of bubble
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
margin EdgeInsetsGeometry?
margin
final
padding EdgeInsetsGeometry?
padding
final
radius BorderRadius
radius
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
shadowElevation double
final
shadowOccluder bool
final
type BubbleType
left
final
width double?
width and height
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited