PopupMenuController class
pop feed animation alpha controller
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
ValueChanged< int> listener) → void -
hide(
) → void - hide menu
-
isShow(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
int data) → void -
rebuild(
) → void - rebuild items and subviews
-
removeListener(
ValueChanged< int> listener) → void -
show(
) → void - show menu
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited